@@ -13,7 +13,7 @@ import botocore
 from botocore.config import Config
 from pytz import timezone
 
-from constant import (
+from .constant import (
     BASKING_API_URL,
     TIMEOUT_MESSAGE
 )
