@@ -7,10 +7,8 @@ Basking.io — Python SDK
 import json
 import logging
 from datetime import datetime, timedelta
-import calendar
 
 import pandas as pd
-from pytz import timezone
 
 
 class Occupancy:
